import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sds_flutter/sds_flutter.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        // This is the theme of your application.
        //
        // Try running your application with "flutter run". You'll see the
        // application has a blue toolbar. Then, without quitting the app, try
        // changing the primarySwatch below to Colors.green and then invoke
        // "hot reload" (press "r" in the console where you ran "flutter run",
        // or simply save your changes to "hot reload" in a Flutter IDE).
        // Notice that the counter didn't reset back to zero; the application
        // is not restarted.
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final TextEditingController controller = TextEditingController();

  int _counter = 0;

  List<int> products = List<int>.generate(25, (index) => index);

  void _incrementCounter() {
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Column(
              children: [
                const Text(
                  'You have pushed the button this many times:',
                ),
                Text(
                  '$_counter',
                  style: Theme.of(context).textTheme.headline4,
                ),
                testTextBtn(),
                testElavetedBtn(),
                SdsTextFormField(
                  SdsTextFormFieldModel(
                    controller: controller,
                    // obscureText: true,
                    iconLeading: const Icon(Icons.phone_android),
                    inputFormatters: InputFormatters.foreignComma,
                  ),
                ),
              ],
            ),
            testList(),
            // testReorder(),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        child: const Icon(Icons.add),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }

  Widget testReorder() {
    return Expanded(
      child: SdsReorderableListView(
        headerBuilder: const ListTile(
          title: Text(
            'Header',
          ),
        ),
        footerBuilder: const ListTile(
          title: Text(
            'footerBuilder',
          ),
        ),
        onReorder: (int oldIndex, int newIndex) {
          setState(() {
            if (newIndex <= products.length) {
              if (newIndex > oldIndex) {
                newIndex--;
              }
              final items = products.removeAt(oldIndex);
              products.insert(newIndex, items);
            }
          });
        },
        children: [
          for (int index = 0; index < products.length; index++)
            ListTile(
              key: Key('$index'),
              title: Text('Item ${products[index]}'),
            ),
        ],
      ),
    );
  }

  Widget testList() {
    return Expanded(
        child: SdsEasyListView(
      padding: EdgeInsets.zero,
      itemCount: products.length,
      itemBuilder: (cxt, index) {
        return ListTile(
          key: Key('$index'),
          title: Text('Item ${products[index]}'),
        );
      },
      headerBuilder: const ListTile(
        title: Text(
          'Header 1',
        ),
      ),
      footerBuilder: const ListTile(
        title: Text(
          'footerBuilder',
        ),
      ),
      scrollbarEnable: false,
    ));
  }

  Widget testTextBtn() {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: SdsTextButton(
        onPressed: () {
          print('SdsTextButton');
        },
        child: const Text("Text Đăng nhập"),
      ),
    );
  }

  Widget testElavetedBtn() {
    RxBool isLoad = false.obs;
    return Obx(
      () => Padding(
        padding: const EdgeInsets.all(8.0),
        child: SdsElevatedButton(
          title: "Đăng nhập",
          onPressed: () {
            isLoad.value = true;
            print('SdsElevatedButton');
            2.delay().then((value) {
              isLoad.value = false;
            });
          },
          isLoading: isLoad.value,
        ),
      ),
    );
  }
}
