import 'package:flutter/material.dart';
import 'package:sds_flutter/const/dimens.dart';
import 'package:sds_flutter/const/src_const.dart';

class SdsElevatedButton extends StatelessWidget {
  final String title;

  final VoidCallback? onPressed;

  final VoidCallback? onLongPress;

  final Widget? loadingBuilder;

  final List<Color> colors;

  final double height;

  final bool isLoading;

  final bool showLoading;

  SdsElevatedButton({
    required this.title,
    required this.onPressed,
    this.loadingBuilder,
    this.colors = colorGradientOrange,
    this.height = btnMedium,
    this.isLoading = false,
    this.showLoading = true,
    this.onLongPress,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: height,
      decoration: BoxDecoration(
          gradient: LinearGradient(colors: colors),
          borderRadius: BorderRadius.circular(8)),
      child: ElevatedButton(
        onPressed: !isLoading
            ? () {
                this.onPressed?.call();
              }
            : () {},
        onLongPress: this.onLongPress,
        style: ElevatedButton.styleFrom(
          primary: Colors.transparent,
          onPrimary: Colors.transparent,
          shadowColor: Colors.transparent,
          shape:
              RoundedRectangleBorder(borderRadius: BorderRadius.circular(8.0)),
        ),
        child: Stack(
          children: [
            Center(
              child: Text(title,
                  style: const TextStyle(
                      fontSize: fontMedium, color: Colors.white)),
            ),
            Align(
              alignment: Alignment.centerRight,
              child: Visibility(
                visible: isLoading && showLoading,
                child: loadingBuilder ??
                    Container(
                      height: btnSmall,
                      width: btnSmall,
                      child: const CircularProgressIndicator(
                        strokeWidth: 2,
                        backgroundColor: Colors.white,
                        valueColor: AlwaysStoppedAnimation<Color>(colorError),
                      ),
                    ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
