import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:sds_flutter/lib_input/text_form_model.dart';

class SdsTextFormField extends StatelessWidget {
  final SdsTextFormFieldModel sdsInputTexFormFieldModel;

  const SdsTextFormField(this.sdsInputTexFormFieldModel);

  @override
  Widget build(BuildContext context) {
    RxBool _isShowButtonClear = false.obs;
    RxBool _showPassword = false.obs;
    sdsInputTexFormFieldModel.controller.addListener(() {
      if (sdsInputTexFormFieldModel.controller.text.isNotEmpty) {
        _isShowButtonClear.value = true;
      }
    });
    _showPassword.value = sdsInputTexFormFieldModel.obscureText;

    Widget? _suffix() {
      if (sdsInputTexFormFieldModel.suffix != null)
        return sdsInputTexFormFieldModel.suffix;
      if (sdsInputTexFormFieldModel.obscureText)
        return GestureDetector(
          onTap: () => _showPassword.toggle(),
          child: Icon(
            _showPassword.value
                ? Icons.visibility_off_outlined
                : Icons.remove_red_eye_outlined,
            color: Colors.grey.shade500,
          ),
        );
      if (!_isShowButtonClear.value || sdsInputTexFormFieldModel.isReadOnly)
        return null;
      return Visibility(
        visible:
            _isShowButtonClear.value && !sdsInputTexFormFieldModel.isReadOnly,
        child: GestureDetector(
          onTap: () {
            sdsInputTexFormFieldModel.controller..clear();

            _isShowButtonClear.value = false;
          },
          child: Icon(
            Icons.clear,
            size: 20,
            color: Colors.grey.shade500,
          ),
        ),
      );
    }

    return Obx(
      () => TextFormField(
        maxLines: sdsInputTexFormFieldModel.maxLines,
        inputFormatters: sdsInputTexFormFieldModel.getFormatters(),
        validator: sdsInputTexFormFieldModel.validator,
        autovalidateMode: AutovalidateMode.onUserInteraction,
        onChanged: (v) {
          if (!_isShowButtonClear.value || v.isEmpty) {
            _isShowButtonClear.value = v.isNotEmpty;
          }
          sdsInputTexFormFieldModel.onChanged?.call(v);
        },
        textInputAction: sdsInputTexFormFieldModel.iconNextTextInputAction,
        style: sdsInputTexFormFieldModel.style,
        controller: sdsInputTexFormFieldModel.controller,
        obscureText: _showPassword.value,
        autofocus: sdsInputTexFormFieldModel.autoFocus,
        focusNode: sdsInputTexFormFieldModel.currentNode,
        keyboardType: sdsInputTexFormFieldModel.textInputType,
        readOnly: sdsInputTexFormFieldModel.isReadOnly,
        maxLength: sdsInputTexFormFieldModel.maxLengthInputForm,
        onFieldSubmitted: (v) {
          if (sdsInputTexFormFieldModel.iconNextTextInputAction ==
              TextInputAction.next) {
            FocusScope.of(context)
                .requestFocus(sdsInputTexFormFieldModel.nextNode);

            sdsInputTexFormFieldModel.onNext?.call(v);
          } else {
            sdsInputTexFormFieldModel.submitFunc?.call(v);
          }
        },
        decoration: InputDecoration(
          counterText: sdsInputTexFormFieldModel.isShowCounterText ? null : '',
          filled: true,
          fillColor: sdsInputTexFormFieldModel.fillColor,
          hintStyle: sdsInputTexFormFieldModel.hintStyle ??
              const TextStyle(
                fontSize: 16,
                color: Colors.white30,
              ),
          hintText: sdsInputTexFormFieldModel.hintText,
          errorStyle: sdsInputTexFormFieldModel.errorStyle ??
              TextStyle(color: Colors.amber.shade300),
          prefixIcon: sdsInputTexFormFieldModel.iconLeading,
          prefixStyle: sdsInputTexFormFieldModel.prefixStyle ??
              const TextStyle(color: Colors.red, backgroundColor: Colors.white),
          border: OutlineInputBorder(
              borderRadius:
                  BorderRadius.circular(sdsInputTexFormFieldModel.borderRadius),
              borderSide: BorderSide.none),
          contentPadding: const EdgeInsets.all(12.0),
          suffix: _suffix(),
        ),
      ),
    );
  }
}
