import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'text_input_formatter.dart';

class SdsTextFormFieldModel {
  final Widget? iconLeading;

  final String? hintText;

  final TextEditingController controller;

  final FocusNode? currentNode;

  final FocusNode? nextNode;

  final bool obscureText;

  final double borderRadius;

  final TextInputAction iconNextTextInputAction;

  final ValueChanged<String>? submitFunc;

  final ValueChanged<String>? onNext;

  final FormFieldValidator<String>? validator;

  final InputFormatters inputFormatters;

  final TextInputType textInputType;

  /// The [maxLength] must be null, -1 or greater than zero. If it is null or -1
  /// then no limit is enforced.
  final int? maxLengthInputForm;

  final bool isReadOnly;

  final bool autoFocus;

  final Color? fillColor;

  final ValueChanged<String>? onChanged;

  final int maxLines;

  final Widget? suffix;

  final bool isShowCounterText;

  final TextStyle? style;

  final TextStyle? hintStyle;

  final TextStyle? errorStyle;

  final TextStyle? prefixStyle;

  SdsTextFormFieldModel({
    this.iconLeading,
    this.hintText,
    required this.controller,
    this.currentNode,
    this.submitFunc,
    this.nextNode,
    this.obscureText = false,
    this.iconNextTextInputAction = TextInputAction.next,
    this.onNext,
    this.validator,
    this.inputFormatters = InputFormatters.lengthLimitingText,
    this.borderRadius = 10.0,
    this.textInputType = TextInputType.text,
    this.maxLengthInputForm,
    this.isReadOnly = false,
    this.autoFocus = false,
    this.fillColor,
    this.onChanged,
    this.maxLines = 1,
    this.suffix,
    this.isShowCounterText = true,
    this.style,
    this.hintStyle,
    this.errorStyle,
    this.prefixStyle,
  });

  List<TextInputFormatter> getFormatters() {
    switch (inputFormatters) {
      case InputFormatters.digitsOnly:
        return [
          FilteringTextInputFormatter.digitsOnly,
          LengthLimitingTextFieldFormatterFixed(maxLengthInputForm),
        ];
      case InputFormatters.taxCode:
        return [
          TaxCodeFormatter(),
          FilteringTextInputFormatter.allow(RegExp(r"[0-9-]")),
          LengthLimitingTextInputFormatter(maxLengthInputForm ?? 14),
        ];
      case InputFormatters.english:
        return [
          FilteringTextInputFormatter.allow(RegExp(r'[a-zA-Z0-9-_\.]')),
        ];
      case InputFormatters.vndComma:
        return [
          NumericTextFormatter(),
        ];
      case InputFormatters.vndDot:
        return [
          NumericTextFormatter(isDot: true),
        ];
      case InputFormatters.foreignDot:
        return [
          NumericTextFormatter(type: 1, isDot: true),
        ];
      case InputFormatters.foreignComma:
        return [
          NumericTextFormatter(type: 1),
        ];
      default:
        return [LengthLimitingTextFieldFormatterFixed(maxLengthInputForm)];
    }
  }
}

enum InputFormatters {
  /// Giới hạn ký tự nhập (nếu có)
  lengthLimitingText,

  /// Chỉ nhập số, giới hạn ký tự
  digitsOnly,

  /// Kiểu nhập là mã số thuế
  taxCode,

  /// Không cho nhập các ký tự đặc biệt. dấu cách
  english,

  /// Nhập đơn vị tiền tệ Việt Nam,
  ///
  /// 9 số phân cách bởi dấu '.'
  vndDot,

  /// Nhập đơn vị tiền tệ Việt Nam,
  ///
  /// 9 số phân cách bởi dấu ','
  vndComma,

  /// Nhập đơn vị tiền tệ nước ngoài
  ///
  /// 9 số phân cách bởi dấu '.'
  ///
  /// 5 số sau thập phân, phân cách bởi dấu ','
  foreignDot,

  /// Nhập đơn vị tiền tệ nước ngoài
  ///
  /// 9 số phân cách bởi dấu ','
  ///
  /// 5 số sau thập phân, phân cách bởi dấu '.'
  foreignComma,
}
